==> cmsmadesimple-1.10.3-full.tar.gz: modules/FileManager/lang/ext/nb_NO.php <==
<?php
$lang['friendlyname'] = 'Filbehandler';
$lang['permission'] = 'Bruk av Filbehandler modulen';
$lang['permissionadvanced'] = 'Avansert bruk av Filbehandler modulen';
$lang['moddescription'] = 'Behandling av filer og kataloger i opplasting(uploads)-filseksjonen av cmsms';
$lang['installed'] = 'Filbehandler versjon %s installert';
$lang['postinstall'] = 'Filbehandler modul ble installert';
$lang['uninstalled'] = 'Filbehandler modul avinstallert';
$lang['really_uninstall'] = 'Er du sikker p&aring; at Filbehandler modulen skal avinstalleres';
$lang['upgraded'] = 'Filbehandler modulen ble oppgradert til versjon %s';
$lang['fileview'] = 'Fil visning';
$lang['switchtofileview'] = 'Skift til fil visning';
$lang['settings'] = 'Innstillinger';
$lang['savesettings'] = 'Lagre innstillinger';
$lang['postletexists'] = 'Advarsel! Vennligst fjern modules/File Manager/postlet katalogen helt, da dette har blitt foreldet for mange, mange versjoner siden.';
$lang['filename'] = 'Filnavn';
$lang['fileinfo'] = 'Filinfo ';
$lang['fileowner'] = 'Fileier';
$lang['fileperms'] = 'Tillatelser';
$lang['filesize'] = 'St&oslash;rrelse';
$lang['filedate'] = 'Dato';
$lang['actions'] = 'Handlinger';
$lang['delete'] = 'Slett';
$lang['notwritable'] = 'Ikke skrivbar';
$lang['afileistoobig'] = 'En fil er for stor. Opplasting avbrutt.';
$lang['unknown'] = 'Ukjent';
$lang['fileoutsideuploads'] = 'Du har IKKE tillatelse til &aring; modifisere filer utenfor uploads-katalogen! (Dette vil kreve at du har tildelt Advanced File Management tillatelsen)';
$lang['writable'] = 'Skrivbar';
$lang['writeprotected'] = 'Skrivebeskyttet';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'Mb';
$lang['files'] = 'filer';
$lang['bytesin'] = 'bytes i';
$lang['in'] = 'i';
$lang['file'] = 'fil';
$lang['fileno'] = 'Filnr.';
$lang['subdirs'] = 'underkataloger';
$lang['subdir'] = 'underkatalog';
$lang['and'] = 'og';
$lang['confirmsingledelete'] = 'Er du sikker?';
$lang['confirmsingledirdelete'] = 'Er du sikker p&aring; at mappen skal slettes?';
$lang['dirtreedeletesuccess'] = 'Mappen inkludert innhold ble slettet.';
$lang['dirtreedeletefail'] = 'En feil oppstod under sletting av denne katalogen. Noe av innholdet kan likevel ha blitt slettet.';
$lang['singlefiledeletesuccess'] = 'Filen ble slettet';
$lang['filedeletesuccess'] = 'ble slettet';
$lang['singlefiledeletefail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; slette filen';
$lang['filedeletefail'] = ' ble ikke slettet grunnet en feil';
$lang['singledirdeletesuccess'] = 'Katalogen ble slettet';
$lang['singledirdeletefail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; slette katalogen (er den tom?)';
$lang['deleteselected'] = 'Slett de valgte filene';
$lang['confirmselected'] = 'Er du sikker?';
$lang['confirmdeleteselected'] = 'Er du sikker p&aring; at de valgte filene skal slettes?';
$lang['deleteselectedcancelled'] = 'Sletting av valgte filer avbrutt';
$lang['recursetext'] = 'Recurse into subdirs (not yet implemented)';
$lang['nofilesselected'] = 'Ingen filer valgt';
$lang['moveselected'] = 'Flytt de valgte filene';
$lang['copyselected'] = 'Kopier de valgte filene';
$lang['selecttargetdir'] = 'Velg m&aring;lmappe for &aring; flytte/kopiere';
$lang['movedto'] = 'flyttet til';
$lang['copiedto'] = 'kopiert til';
$lang['couldnotmove'] = 'kunne ikke flyttes';
$lang['couldnotcopy'] = 'kunne ikke kopieres';
$lang['filesdeletedsuccessfully'] = '%s fil(er) ble slettet';
$lang['filesdeletedfiled'] = '%s fil(er) feilet i &aring; bli slettet';
$lang['filesmovedsuccessfully'] = '%s fil(er) ble flyttet';
$lang['filesmovedfailed'] = '%s fil(er) feilet i &aring; bli flyttet';
$lang['filescopiedsuccessfully'] = '%s fil(er) ble kopiert';
$lang['filescopiedfailed'] = '%s fil(er) feilet i &aring; bli kopiert';
$lang['internalerror'] = 'Intern feil (betyr at noe ikke hadde mening i det hele tatt, vennligst rapporter hva du gjorde)';
$lang['rename'] = 'Omd&oslash;p';
$lang['newname'] = 'Nytt navn:';
$lang['renamesuccess'] = 'Filen ble omd&oslash;pt';
$lang['renamefailure'] = 'Omd&oslash;ping feilet';
$lang['renamecancelled'] = 'Omd&oslash;ping avbrutt';
$lang['owner'] = 'Eier(Owner)';
$lang['group'] = 'Gruppe(Group)';
$lang['others'] = 'Andre(Others)';
$lang['newpermissions'] = 'Nye rettigheter:';
$lang['setpermissions'] = 'Sett rettigheter';
$lang['permissionstyle'] = 'Rettighets stil';
$lang['rwxstyle'] = 'rwx stil';
$lang['755style'] = '755 stil';
$lang['quickmode'] = 'Quick chmod (f.eks. 777)';
$lang['chmod'] = 'Endre rettigheter';
$lang['chmodselected'] = 'Endre rettigheter p&aring; valgte filer';
$lang['chmodsuccess'] = 'Filen fikk nye rettigheter';
$lang['chmodfailure'] = 'Endring av rettigheter p&aring; filen feilet';
$lang['chmodcancelled'] = 'Endring av rettigheter avbrutt';
$lang['newuploadfailed'] = '%s fil(er) feilet i &aring; bli lastet opp (eller muligens &aring; pakke ut)';
$lang['newuploadsuccess'] = '%s fil(er) ble lastet opp (og pakket ut om dette var valgt)';
$lang['dirchmodfailmulti'] = '&Aring; endre rettigheter p&aring; katalogen mislyktes, men mulig noe av innholdet likevel kan ha f&aring;tt nye rettigheter.';
$lang['dirchmodsuccessmulti'] = 'Endre rettigheter p&aring; katalogen og dets innhold var vellykket';
$lang['dirchmodsuccess'] = 'Katalogen ble vellykket endret med nye rettigheter';
$lang['dirchmodfailure'] = 'Endring av rettigheter p&aring; katalog feilet';
$lang['dirnotemptyconfirm'] = 'Denne katalogen er ikke tom. Vil du virkelig slette den og alt innhold, inkludert underkataloger?';
$lang['dirtreedeletecancelled'] = 'Sletting av kataloger avbrutt';
$lang['imsure'] = 'Jeg er sikker!';
$lang['cancel'] = 'Avbryt';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Last opp ny(e) fil(er):';
$lang['unpackafterupload'] = 'Fors&oslash;k &aring; pakke opp filen etter opplasting (kun tgz og de fleste zip-filer)?';
$lang['uploadsuccess'] = 'ble lastet opp';
$lang['uploadfail'] = 'opplastingen feilet ';
$lang['unpacksuccess'] = 'ble pakket ut';
$lang['unpackfail'] = 'feilet med denne feilmeldingen:';
$lang['packfileopenfail'] = 'Kunne ikke &aring;pne den pakkede filen for utpakking (format som ikke st&oslash;ttes?)';
$lang['packfilewritefail'] = 'Kunne ikke &aring;pne filen %s for skriving';
$lang['afilecontainsillegalchars'] = 'Et filnavn inneholder en eller flere ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$). Opplasting avbrutt.';
$lang['currentpath'] = 'Gjeldende bane:';
$lang['newdirname'] = 'Opprett ny katalog:';
$lang['newdirsuccess'] = 'Katalogen ble opprettet';
$lang['newdirfail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; opprette katalogen';
$lang['direxists'] = 'Katalogen eksisterer allerede';
$lang['invalidnewdir'] = 'Navnet p&aring; katalogen kan ikke inneholde tegn som  /, \ og &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s ';
$lang['iconsize'] = 'Ikonst&oslash;rrelse';
$lang['smallicons'] = 'Sm&aring; ikoner';
$lang['largeicons'] = 'Store ikoner';
$lang['thousanddelimiter'] = 'tusen-skilletegn';
$lang['none'] = 'Ingen';
$lang['space'] = 'mellomrom';
$lang['showthumbnails'] = 'Vis miniatyrbilder';
$lang['showthumbnailshelp'] = '&Aring; sl&aring; p&aring; dette vil vise miniatyrbildene for bildefiler om disse eksisterer og vil skjule de faktiske miniatyrbildefilene. &Aring; sl&aring; av vil vise alle filer.';
$lang['uploadfilesto'] = 'Laste opp filer til:';
$lang['uploadview'] = 'Last opp filer';
$lang['uploadboxes'] = 'Antall opplastingsbokser';
$lang['nothinguploaded'] = 'Ingenting lastet opp';
$lang['newunsupportedarchive'] = '%s er et ust&oslash;ttet arkivformat';
$lang['uploadmethod'] = 'Opplastingsmetode';
$lang['uploaderstandard'] = 'Standard html innskrivingsmetode (tillater utpakking)';
$lang['enableadvanced'] = 'Sl&aring; p&aring; avansert modus?';
$lang['advancedhelp'] = 'Lar deg f&aring; tilgang til hele cmsms filsystemet, ikke kun /uploads/ (om tillatt)';
$lang['showhiddenfileshelp'] = 'Bare brukt om avansert mode er p&aring;sl&aring;tt';
$lang['showhiddenfiles'] = 'Vis skjulte filer';
$lang['settingsconfirmsingledelete'] = 'Bekreft sletting av en enkelt fil?';
$lang['settingssaved'] = 'Innstillinger lagret';
$lang['help'] = '		<h3>Hva gj&oslash;r denne?</h3>
		<p>Denne modulen tilbyr filbehandlingsfunksjoner.</p>
		<h3>Hvordan bruker jeg denne?</h3>
		<p>Velg den fra innholdmenyen i administrasjon.</p>';
$lang['utmz'] = '156861353.1302963072.3784.82.utmcsr=cmsms.eu|utmccn=(referral)|utmcmd=referral|utmcct=/';
$lang['utma'] = '156861353.179052623084110100.1210423577.1306670563.1306673866.3886';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.11-full.tar.gz: modules/FileManager/lang/ext/nb_NO.php <==
<?php
$lang['invaliddestname'] = 'Destinasjonsnavnet som er oppgitt er enten tomt eller ugyldig';
$lang['copysuccess'] = 'Elementer ble kopiert';
$lang['copyfailed'] = 'Kopieringshandlingen feilet p&aring; %s';
$lang['ie_upload_message'] = 'Dra og slipp, eller fler-filopplasting er ikke tilgjengelig i Internet Explorer. For &aring; aktivere disse funksjonene m&aring; du benytte en mer kapabel nettleser som Firefox eller Chrome';
$lang['confirm_unpack'] = 'Er du sikker p&aring; at du vil pakke ut dette arkivett?';
$lang['copy_destdir'] = 'M&aring;lkatalog';
$lang['copy_destname'] = 'M&aring;l filnavn';
$lang['itemstocopy'] = 'Kopier disse elementene';
$lang['prompt_copy'] = 'Kopier en eller flere elementer';
$lang['movesuccess'] = 'Elementer ble flyttet';
$lang['movefailed'] = 'Flyttehandlingen feilet p&aring; %s';
$lang['fileexistsdest'] = '%s finnes allerede p&aring; m&aring;lomr&aring;det';
$lang['insufficientpermission'] = 'Utilstrekkelige rettigheter for %s';
$lang['invalidmovedir'] = 'M&aring;lkatalogen som er oppgitt er ugyldig';
$lang['namealreadyexists'] = 'Navnet eksisterer allerede';
$lang['movedestdirsame'] = 'M&aring;lkatalogen som er oppgitt er samme som kilde';
$lang['prompt_move'] = 'Flytt elementer til annen katalog';
$lang['info_move'] = 'Dette alternativet vil tillate flytting av ett eller flere elementer til en annen katalog. Bruk dette med forsiktighet da dette kan bryte lenker til filer, eller bryte annen funksjonalitet p&aring; nettsiden';
$lang['itemstomove'] = 'Flytt disse elementene';
$lang['move_destdir'] = 'M&aring;lkatalog';
$lang['nodestinationdirs'] = 'Klarte ikke &aring; finne noen gyldig m&aring;lkatalog for handlingen';
$lang['deletesuccess'] = 'Elementer ble slettet';
$lang['return'] = 'Tilbake';
$lang['error_thumbnotwritable'] = '%s har et miniatyrbilde hvor det ikke er skrive rettighet';
$lang['error_dirnotempty'] = 'Katalog %s er ikke tom';
$lang['error_notwritable'] = 'Ingen skrive rettghet p&aring; %s';
$lang['actiondelete'] = 'Slett en eller flere elementer';
$lang['thumberror'] = 'Problem med &aring; opprette miniatyrbilde';
$lang['thumbsuccess'] = 'Miniatyrbilde ble opprettet';
$lang['create'] = 'Opprett';
$lang['info_createthumb'] = 'Det f&oslash;lgende miniatyrbildet vil bli opprettet';
$lang['createthumbnail'] = 'Opprett <em>(eller gjenskap)</em> et miniatyrbilde';
$lang['info_create_thumbnails'] = 'Om aktivert, s&aring; vil miniatyrbilder for bilder bli opprettet ved opplasting';
$lang['create_thumbnails'] = 'Opprett miniatyrbilder ved opplasting';
$lang['eventdesc_OnFileUploaded'] = 'Sendt n&aring;r en fil er lastet opp';
$lang['eventhelp_OnFileUploaded'] = '<h4>Parametere:</h4>
<ul>
<li>&quot;file&quot; - Den komplette filspesifikasjonen til filen du lastet opp</li>.
<li>&quot;thumb&quot; - Hvis generert, hele filspesifikasjonen til det genererte miniatyrbildet</li>
</ul>';
$lang['ok'] = 'OK ';
$lang['folder'] = 'Mappe';
$lang['change_working_folder'] = 'Endre gjeldende mappe';
$lang['prompt_dropfiles'] = 'Slipp filer her for &aring; laste dem opp';
$lang['refresh'] = 'oppfrisk';
$lang['friendlyname'] = 'Filbehandler';
$lang['permission'] = 'Bruk av Filbehandler modulen';
$lang['permissionadvanced'] = 'Avansert bruk av Filbehandler modulen';
$lang['moddescription'] = 'Behandling av filer og kataloger i opplasting(uploads)-filseksjonen av cmsms';
$lang['installed'] = 'Filbehandler versjon %s installert';
$lang['postinstall'] = 'Filbehandler modul ble installert';
$lang['uninstalled'] = 'Filbehandler modul avinstallert';
$lang['really_uninstall'] = 'Er du sikker p&aring; at Filbehandler modulen skal avinstalleres';
$lang['upgraded'] = 'Filbehandler modulen ble oppgradert til versjon %s';
$lang['fileview'] = 'Fil visning';
$lang['switchtofileview'] = 'Skift til fil visning';
$lang['settings'] = 'Innstillinger';
$lang['savesettings'] = 'Lagre innstillinger';
$lang['postletexists'] = 'Advarsel! Vennligst fjern modules/File Manager/postlet katalogen helt, da dette har blitt foreldet for mange, mange versjoner siden.';
$lang['filename'] = 'Filnavn';
$lang['fileinfo'] = 'Filinfo ';
$lang['fileowner'] = 'Fileier';
$lang['fileperms'] = 'Tillatelser';
$lang['filesize'] = 'St&oslash;rrelse';
$lang['filedate'] = 'Dato';
$lang['actions'] = 'Handlinger';
$lang['newdir'] = 'Ny katalog';
$lang['createnewdir'] = 'Opprett ny katalog';
$lang['rename'] = 'Omd&oslash;p';
$lang['renameerror'] = 'Feil! Kunne ikke endre navn p&aring; element';
$lang['delete'] = 'Slett';
$lang['thumbnail'] = 'Opprett miniatyrbilde';
$lang['copy'] = 'Kopier';
$lang['move'] = 'Flytt';
$lang['unpack'] = 'Pakk ut';
$lang['notwritable'] = 'Ikke skrivbar';
$lang['afileistoobig'] = 'En fil er for stor. Opplasting avbrutt.';
$lang['unknown'] = 'Ukjent';
$lang['fileoutsideuploads'] = 'Du har IKKE tillatelse til &aring; modifisere filer utenfor uploads-katalogen! (Dette vil kreve at du har tildelt Advanced File Management tillatelsen)';
$lang['writable'] = 'Skrivbar';
$lang['writeprotected'] = 'Skrivebeskyttet';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'Mb';
$lang['files'] = 'filer';
$lang['bytesin'] = 'bytes i';
$lang['in'] = 'i';
$lang['file'] = 'fil';
$lang['fileno'] = 'Filnr.';
$lang['subdirs'] = 'underkataloger';
$lang['subdir'] = 'underkatalog';
$lang['and'] = 'og';
$lang['unknownfileaction'] = 'Intern feil: ukjent filhandling';
$lang['confirmsingledelete'] = 'Er du sikker?';
$lang['confirmsingledirdelete'] = 'Er du sikker p&aring; at katalogen skal slettes?';
$lang['dirtreedeletesuccess'] = 'Mappen inkludert innhold ble slettet.';
$lang['dirtreedeletefail'] = 'En feil oppstod under sletting av denne katalogen. Noe av innholdet kan likevel ha blitt slettet.';
$lang['singlefiledeletesuccess'] = 'Filen ble slettet';
$lang['filedeletesuccess'] = 'ble slettet';
$lang['singlefiledeletefail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; slette filen';
$lang['filedeletefail'] = ' ble ikke slettet grunnet en feil';
$lang['singledirdeletesuccess'] = 'Katalogen ble slettet';
$lang['singledirdeletefail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; slette katalogen (er den tom?)';
$lang['deleteselected'] = 'Slett de valgte filene';
$lang['confirmselected'] = 'Er du sikker?';
$lang['confirmdeleteselected'] = 'Er du sikker p&aring; at de valgte filene skal slettes?';
$lang['deleteselectedcancelled'] = 'Sletting av valgte filer avbrutt';
$lang['recursetext'] = 'Recurse into subdirs (not yet implemented)';
$lang['nofilesselected'] = 'Ingen filer valgt';
$lang['morethanonefiledirselected'] = 'Kun en fil eller katalog skal markeres for denne handlingen.';
$lang['moveselected'] = 'Flytt de valgte filene';
$lang['copyselected'] = 'Kopier de valgte filene';
$lang['selecttargetdir'] = 'Velg m&aring;lmappe for &aring; flytte/kopiere';
$lang['movedto'] = 'flyttet til';
$lang['copiedto'] = 'kopiert til';
$lang['couldnotmove'] = 'kunne ikke flyttes';
$lang['couldnotcopy'] = 'kunne ikke kopieres';
$lang['filesdeletedsuccessfully'] = '%s fil(er) ble slettet';
$lang['filesdeletedfiled'] = '%s fil(er) feilet i &aring; bli slettet';
$lang['filesmovedsuccessfully'] = '%s fil(er) ble flyttet';
$lang['filesmovedfailed'] = '%s fil(er) feilet i &aring; bli flyttet';
$lang['filescopiedsuccessfully'] = '%s fil(er) ble kopiert';
$lang['filescopiedfailed'] = '%s fil(er) feilet i &aring; bli kopiert';
$lang['internalerror'] = 'Intern feil (betyr at noe ikke hadde mening i det hele tatt, vennligst rapporter hva du gjorde)';
$lang['newname'] = 'Nytt navn:';
$lang['renamesuccess'] = 'Element ble omd&oslash;pt';
$lang['renamefailure'] = 'Omd&oslash;ping feilet';
$lang['renamecancelled'] = 'Omd&oslash;ping avbrutt';
$lang['owner'] = 'Eier(Owner)';
$lang['group'] = 'Gruppe(Group)';
$lang['others'] = 'Andre(Others)';
$lang['newpermissions'] = 'Nye rettigheter:';
$lang['setpermissions'] = 'Sett rettigheter';
$lang['permissionstyle'] = 'Rettighets stil';
$lang['rwxstyle'] = 'rwx stil';
$lang['755style'] = '755 stil';
$lang['quickmode'] = 'Quick chmod (f.eks. 777)';
$lang['chmod'] = 'Endre rettigheter';
$lang['chmodselected'] = 'Endre rettigheter p&aring; valgte filer';
$lang['chmodsuccess'] = 'Filen fikk nye rettigheter';
$lang['chmodfailure'] = 'Endring av rettigheter p&aring; filen feilet';
$lang['chmodcancelled'] = 'Endring av rettigheter avbrutt';
$lang['newuploadfailed'] = '%s fil(er) feilet i &aring; bli lastet opp (eller muligens &aring; pakke ut)';
$lang['newuploadsuccess'] = '%s fil(er) ble lastet opp (og pakket ut om dette var valgt)';
$lang['dirchmodfailmulti'] = '&Aring; endre rettigheter p&aring; katalogen mislyktes, men mulig noe av innholdet likevel kan ha f&aring;tt nye rettigheter.';
$lang['dirchmodsuccessmulti'] = 'Endre rettigheter p&aring; katalogen og dets innhold var vellykket';
$lang['dirchmodsuccess'] = 'Katalogen ble vellykket endret med nye rettigheter';
$lang['dirchmodfailure'] = 'Endring av rettigheter p&aring; katalog feilet';
$lang['dirnotemptyconfirm'] = 'Denne katalogen er ikke tom. Vil du virkelig slette den og alt innhold, inkludert underkataloger?';
$lang['dirtreedeletecancelled'] = 'Sletting av kataloger avbrutt';
$lang['imsure'] = 'Jeg er sikker!';
$lang['cancel'] = 'Avbryt';
$lang['uploadnewfile'] = 'Last opp ny(e) fil(er):';
$lang['unpackafterupload'] = 'Fors&oslash;k &aring; pakke opp filen etter opplasting (kun tgz og de fleste zip-filer)?';
$lang['uploadsuccess'] = 'ble lastet opp';
$lang['uploadfail'] = 'opplastingen feilet ';
$lang['unpacksuccess'] = 'ble pakket ut';
$lang['unpackfail'] = 'feilet med denne feilmeldingen:';
$lang['packfileopenfail'] = 'Kunne ikke &aring;pne den pakkede filen for utpakking (format som ikke st&oslash;ttes?)';
$lang['packfilewritefail'] = 'Kunne ikke &aring;pne filen %s for skriving';
$lang['afilecontainsillegalchars'] = 'Et filnavn inneholder en eller flere ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$). Opplasting avbrutt.';
$lang['filenotfound'] = 'Filen ble ikke funnet';
$lang['currentpath'] = 'Gjeldende bane:';
$lang['newdirname'] = 'Opprett ny katalog:';
$lang['newdirsuccess'] = 'Katalogen ble opprettet';
$lang['newdirfail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; opprette katalogen';
$lang['direxists'] = 'Katalogen eksisterer allerede';
$lang['invalidnewdir'] = 'Navnet p&aring; katalogen kan ikke inneholde tegn som  /, \ og &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s ';
$lang['iconsize'] = 'Ikonst&oslash;rrelse';
$lang['smallicons'] = 'Sm&aring; ikoner';
$lang['largeicons'] = 'Store ikoner';
$lang['thousanddelimiter'] = 'tusen-skilletegn';
$lang['none'] = 'Ingen';
$lang['space'] = 'mellomrom';
$lang['showthumbnails'] = 'Vis miniatyrbilder';
$lang['showthumbnailshelp'] = '&Aring; sl&aring; p&aring; dette vil vise miniatyrbildene for bildefiler om disse eksisterer og vil skjule de faktiske miniatyrbildefilene. &Aring; sl&aring; av vil vise alle filer.';
$lang['uploadfilesto'] = 'Laste opp filer til:';
$lang['uploadview'] = 'Last opp filer';
$lang['uploadboxes'] = 'Antall opplastingsbokser';
$lang['nothinguploaded'] = 'Ingenting lastet opp';
$lang['newunsupportedarchive'] = '%s er et ust&oslash;ttet arkivformat';
$lang['uploadmethod'] = 'Opplastingsmetode';
$lang['uploaderstandard'] = 'Standard html innskrivingsmetode (tillater utpakking)';
$lang['enableadvanced'] = 'Sl&aring; p&aring; avansert modus?';
$lang['advancedhelp'] = 'Lar deg f&aring; tilgang til hele cmsms filsystemet, ikke kun /uploads/ (om tillatt)';
$lang['showhiddenfileshelp'] = 'Bare brukt om avansert mode er p&aring;sl&aring;tt';
$lang['showhiddenfiles'] = 'Vis skjulte filer';
$lang['settingsconfirmsingledelete'] = 'Bekreft sletting av en enkelt fil?';
$lang['settingssaved'] = 'Innstillinger lagret';
$lang['help'] = '		<h3>Hva gj&oslash;r denne?</h3>
		<p>Denne modulen tilbyr filbehandlingsfunksjoner.</p>
		<h3>Hvordan bruker jeg denne?</h3>
		<p>Velg den fra innholdmenyen i administrasjon.</p>';
$lang['qca'] = 'P0-536849115-1307983495210';
$lang['utma'] = '156861353.33413323.1340640910.1340820370.1340826029.12';
$lang['utmz'] = '156861353.1340640910.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
